@@ -18,11 +18,14 @@ describe 'nova::scheduler' do
     )}
 
     it { is_expected.to contain_nova_config('scheduler/workers').with_value(4) }
-    it { is_expected.to contain_nova_config('scheduler/driver').with_value('filter_scheduler') }
+    it { is_expected.to contain_nova_config('scheduler/driver').with_ensure('absent') }
     it { is_expected.to contain_nova_config('scheduler/discover_hosts_in_cells_interval').with_value('<SERVICE DEFAULT>') }
     it { is_expected.to contain_nova_config('scheduler/query_placement_for_image_type_support').with_value('<SERVICE DEFAULT>') }
     it { is_expected.to contain_nova_config('scheduler/limit_tenants_to_placement_aggregate').with_value('<SERVICE DEFAULT>') }
+    it { is_expected.to contain_nova_config('scheduler/placement_aggregate_required_for_tenants').with_value('<SERVICE DEFAULT>') }
     it { is_expected.to contain_nova_config('scheduler/max_placement_results').with_value('<SERVICE DEFAULT>') }
+    it { is_expected.to contain_nova_config('scheduler/enable_isolated_aggregate_filtering').with_value('<SERVICE DEFAULT>') }
+    it { is_expected.to contain_nova_config('scheduler/query_placement_for_availability_zone').with_value('<SERVICE DEFAULT>') }
 
     it { is_expected.to contain_class('nova::availability_zone') }
 
@@ -85,6 +88,14 @@ describe 'nova::scheduler' do
       it { is_expected.to contain_nova_config('scheduler/limit_tenants_to_placement_aggregate').with_value(true) }
     end
 
+    context 'with placement_aggregate_required_for_tenants' do
+      let :params do
+        { :placement_aggregate_required_for_tenants => true }
+      end
+
+      it { is_expected.to contain_nova_config('scheduler/placement_aggregate_required_for_tenants').with_value(true) }
+    end
+
     context 'with max_placement_results' do
       let :params do
         { :max_placement_results => 10 }
@@ -93,6 +104,22 @@ describe 'nova::scheduler' do
       it { is_expected.to contain_nova_config('scheduler/max_placement_results').with_value(10) }
     end
 
+    context 'with enable_isolated_aggregate_filtering' do
+      let :params do
+        { :enable_isolated_aggregate_filtering => true }
+      end
+
+      it { is_expected.to contain_nova_config('scheduler/enable_isolated_aggregate_filtering').with_value(true) }
+    end
+
+    context 'with query_placement_for_availability_zone' do
+      let :params do
+        { :query_placement_for_availability_zone => true }
+      end
+
+      it { is_expected.to contain_nova_config('scheduler/query_placement_for_availability_zone').with_value(true) }
+    end
+
     context 'with default database parameters' do
       let :pre_condition do
         "include nova"
